@@ -7,7 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package Software::LicenseMoreUtils::LicenseWithSummary;
-$Software::LicenseMoreUtils::LicenseWithSummary::VERSION = '1.002';
+$Software::LicenseMoreUtils::LicenseWithSummary::VERSION = '1.003';
 # ABSTRACT: Software::License with a summary
 
 use strict;
@@ -79,12 +79,14 @@ sub license_class {
 sub debian_text {
     my $self = shift;
     carp "debian_text is deprecated, please use summary_or_text";
-    return $self->summary || $self->fulltext;
+    return $self->summary_or_text;
 }
 
 sub summary_or_text {
     my $self = shift;
-    return $self->summary || $self->fulltext;
+    return join("\n",  grep { $_ } ($self->notice, $self->summary))
+        if length $self->summary;
+    return $self->fulltext;
 }
 
 sub AUTOLOAD {
@@ -108,7 +110,7 @@ Software::LicenseMoreUtils::LicenseWithSummary - Software::License with a summar
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
